==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/sq.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Punë",
    "Due yesterday" : "Mbaron dje",
    "Due today" : "Mbaron sot",
    "Due tomorrow" : "Mbaron nesër",
    "Due on" : "Mbaron më",
    "Started yesterday" : "Filloi dje",
    "Starts today" : "Nis Sot",
    "Starts tomorrow" : "Nis Nesër",
    "Started on" : "U fillua më",
    "Starts on" : "Fillon më",
    "[Remind me yesterday at ]HH:mm" : "[Kujtoma nesër më ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Kujtoma sot më ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Kujtoma nesër më ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Kujtoma më]MMM DD, YYYY,[ më ]HH:mm",
    "Yesterday" : "Dje",
    "Today" : "Sot",
    "Tomorrow" : "Nesër",
    "in %s" : "në %s",
    "%s ago" : "%s më parë",
    "seconds" : "sekonda",
    "a minute" : "një minutë",
    "%d minutes" : "%d minuta",
    "an hour" : "një orë",
    "%d hours" : "%d orë",
    "a day" : "një ditë",
    "%d days" : "%d ditë",
    "a month" : "një muaj",
    "%d months" : "%d muaj",
    "a year" : "një vit",
    "%d years" : "%d vite",
    "week" : "javë",
    "weeks" : "javë",
    "day" : "ditë",
    "days" : "ditë",
    "hour" : "orë",
    "hours" : "orë",
    "minute" : "minutë",
    "minutes" : "minuta",
    "second" : "sekondë",
    "before beginning" : "para fillimit",
    "after beginning" : "pas fillimit",
    "before end" : "para fundit",
    "after end" : "pas fundit",
    "Comment" : "Koment",
    "Add a comment" : "Shtoni një koment",
    "This will delete the Calendar \"%s\" and all of its entries." : "Kjo do të fshijë Kalendarin \"%s\" dhe krejt zërat e tij.",
    "The name \"%s\" is already used." : "Emri \"%s\" është tashmë në përdorim.",
    "An empty name is not allowed." : "Nuk lejohet emër i zbrazët.",
    "Hidden" : "I padukshëm",
    "Visible" : "I dukshëm",
    "Automatic" : "Automatike",
    "Sunday" : "E dielë",
    "Monday" : "E hënë",
    "Tuesday" : "E martë",
    "Wednesday" : "E mërkurë",
    "Thursday" : "E enjte",
    "Friday" : "E premte",
    "Saturday" : "E shtunë",
    "Add an important item in \"%s\"..." : "Shtoni një zë të rëndësishëm te \"%s\"...",
    "Add an item due today in \"%s\"..." : "Shtoni një zë që mbaron sot te \"%s\"...",
    "Add an item in \"%s\"..." : "Shtoni një zë te \"%s\"...",
    "Add a current item in \"%s\"..." : "Shtoni një zë të tanishëm te \"%s\"...",
    "Add a subtask to \"%s\"..." : "Shtoni një nënpunë te \"%s\"…",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Punë e Plotësuar","%n Punë të Plotësuara"],
    "Hours" : "Orë",
    "Minutes" : "Minuta",
    "Set due date" : "Caktoni datë mbarimi",
    "%s %% completed" : "%s %% e plotësuar",
    "priority %s: " : "përparësi %s: ",
    "high" : "e lartë",
    "medium" : "e mesme",
    "low" : "e ulët",
    "no priority assigned" : "s’i është caktuar përparësi",
    "Remind me" : "Kujtoma",
    "at the end" : "në fund",
    "at the beginning" : "në fillim",
    "Set start date" : "Caktoni datë fillimi",
    "{calendar} shared by {owner}" : "{calendar} ndarë nga {owner}",
    "Unnamed" : "E paemër",
    "Important" : "E rëndësishme",
    "Week" : "Javë",
    "All" : "Krejt",
    "Current" : "E tanishmja",
    "Completed" : "Të plotësuara",
    "Delete" : "Fshije",
    "Cancel" : "Anuloje",
    "Edit" : "Përpunoni",
    "Link" : "Lidhje",
    "Download" : "Shkarkoje",
    "Save" : "Ruaje",
    "Add List..." : "Shtoni Listë…",
    "New List" : "Listë e Re",
    "Settings" : "Rregullime",
    "Start of week" : "Fillimi i javës",
    "Visibility of Smart Collections" : "Dukshmëri Koleksionesh të Mençura",
    "Change sort order" : "Ndryshoni rend renditjeje",
    "Default" : "Parazgjedhje",
    "Due date" : "Datë përfundimi",
    "Start date" : "Datë nisjeje",
    "Priority" : "Përparësi",
    "Alphabetically" : "Alfabetikisht",
    "Manually" : "Dorazi",
    "Load remaining completed tasks." : "Ngarko punët e plotësuara të mbetura.",
    "All day" : "Gjithë ditën",
    "(New category)" : "(Kategori e re)",
    "Select categories..." : "Përzgjidhni kategori…",
    "Loading the task..." : "Po ngarkohet puna…",
    "Task not found!" : "S’u gjet punë!",
    "add a subtask to" : "shtoni një nënpunë te"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.9.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/sq.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Detyra",
    "Due yesterday" : "Mbaron dje",
    "Due today" : "Mbaron sot",
    "Due tomorrow" : "Mbaron nesër",
    "Due on" : "Mbaron më",
    "Started yesterday" : "Filloi dje",
    "Starts today" : "Nis Sot",
    "Starts tomorrow" : "Nis Nesër",
    "Started on" : "U fillua më",
    "Starts on" : "Fillon më",
    "[Remind me yesterday at ]HH:mm" : "[Kujtoma nesër më ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Kujtoma sot më ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Kujtoma nesër më ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Kujtoma më]MMM DD, YYYY,[ më ]HH:mm",
    "Yesterday" : "Dje",
    "Today" : "Sot",
    "Tomorrow" : "Nesër",
    "in %s" : "në %s",
    "%s ago" : "%s më parë",
    "seconds" : "sekonda",
    "a minute" : "një minutë",
    "%d minutes" : "%d minuta",
    "an hour" : "një orë",
    "%d hours" : "%d orë",
    "a day" : "një ditë",
    "%d days" : "%d ditë",
    "a month" : "një muaj",
    "%d months" : "%d muaj",
    "a year" : "një vit",
    "%d years" : "%d vite",
    "week" : "javë",
    "weeks" : "javë",
    "day" : "ditë",
    "days" : "ditë",
    "hour" : "orë",
    "hours" : "orë",
    "minute" : "minutë",
    "minutes" : "minuta",
    "second" : "sekondë",
    "before beginning" : "para fillimit",
    "after beginning" : "pas fillimit",
    "before end" : "para fundit",
    "after end" : "pas fundit",
    "Comment" : "Koment",
    "Add a comment" : "Shtoni një koment",
    "This will delete the Calendar \"%s\" and all of its entries." : "Kjo do të fshijë Kalendarin \"%s\" dhe krejt zërat e tij.",
    "The name \"%s\" is already used." : "Emri \"%s\" është tashmë në përdorim.",
    "An empty name is not allowed." : "Nuk lejohet emër i zbrazët.",
    "Hidden" : "I padukshëm",
    "Visible" : "I dukshëm",
    "Automatic" : "Automatike",
    "Sunday" : "E Dielë",
    "Monday" : "E Hënë",
    "Tuesday" : "E martë",
    "Wednesday" : "E mërkurë",
    "Thursday" : "E Enjte",
    "Friday" : "E premte",
    "Saturday" : "E shtunë",
    "Add an important item in \"%s\"..." : "Shtoni një zë të rëndësishëm te \"%s\"...",
    "Add an item due today in \"%s\"..." : "Shtoni një zë që mbaron sot te \"%s\"...",
    "Add an item in \"%s\"..." : "Shto një artikull tek \"%s\"...",
    "Add a current item in \"%s\"..." : "Shtoni një zë të tanishëm te \"%s\"...",
    "Add a subtask to \"%s\"..." : "Shtoni një nënpunë te \"%s\"…",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Punë e Plotësuar","%n Punë të Plotësuara"],
    "Hours" : "Orë",
    "Minutes" : "Minuta",
    "Set due date" : "Caktoni datë mbarimi",
    "%s %% completed" : "%s %% e plotësuar",
    "priority %s: " : "përparësi %s: ",
    "high" : "e lartë",
    "medium" : "e mesme",
    "low" : "e ulët",
    "no priority assigned" : "s’i është caktuar përparësi",
    "Remind me" : "Kujtoma",
    "at the end" : "në fund",
    "at the beginning" : "në fillim",
    "Set start date" : "Caktoni datë fillimi",
    "{calendar} shared by {owner}" : "{calendar} ndarë nga {owner}",
    "Unnamed" : "E paemër",
    "Important" : "E rëndësishme",
    "Week" : "Javë",
    "All" : "Krejt",
    "Current" : "E tanishmja",
    "Completed" : "Të plotësuara",
    "Delete" : "Fshije",
    "Cancel" : "Anuloje",
    "Edit" : "Përpunoni",
    "Link" : "Lidhje",
    "Download" : "Shkarkoje",
    "Save" : "Ruaje",
    "Add List..." : "Shtoni Listë…",
    "New List" : "Listë e Re",
    "Settings" : "Rregullime",
    "Start of week" : "Fillimi i javës",
    "Visibility of Smart Collections" : "Dukshmëri Koleksionesh të Mençura",
    "Change sort order" : "Ndryshoni rend renditjeje",
    "Default" : "Parazgjedhje",
    "Due date" : "Datë përfundimi",
    "Start date" : "Datë nisjeje",
    "Priority" : "Përparësi",
    "Alphabetically" : "Alfabetikisht",
    "Manually" : "Dorazi",
    "Load remaining completed tasks." : "Ngarko punët e plotësuara të mbetura.",
    "Task is completed" : "Detyra është e plotësuar",
    "All day" : "Gjithë ditën",
    "(New category)" : "(Kategori e re)",
    "Select categories..." : "Përzgjidhni kategori…",
    "Loading the task..." : "Po ngarkohet puna…",
    "Task not found!" : "S’u gjet punë!",
    "add a subtask to" : "shtoni një nënpunë te",
    "Toggle subtasks" : "Toggle nëndetyra ",
    "Toggle completed subtasks" : "Toggle kompletoi nëndetyrat"
},
"nplurals=2; plural=(n != 1);");
